@@ -112,7 +112,6 @@ def download_pyrosetta_wheel(prefix, location):
                 if not os.path.isdir(location): os.makedirs(location)
                 print(f'Moving wheel file {f} to target dir {location}...')
                 shutil.move(f'{tmpdirname}/{f}', f'{location}/{f}')
-                print('Downloading... Done!')
                 return(f'{location}/{f}')
 
         print('ERROR: Wheel download has not worked correctly, ABORTING...')
@@ -169,7 +168,7 @@ def install_pyrosetta_on_colab(prefix=_DEFAULT_PYROSETTA_GOOGLE_DRIVE_INSTALL_PR
 
     if wheels:
         wheel = pyrosetta_wheels_path + '/' + sorted(wheels)[-1]
-        print(f'Found compatible wheel: {pyrosetta_wheels_path}/{wheel}')
+        print(f'Found compatible wheel: {wheel}')
     else:
         wheel = download_pyrosetta_wheel(mount_google_drive() + '/' + prefix, pyrosetta_wheels_path)
         print(f'Installing PyRosetta wheel {wheel!r}...')
